Certificate class

Annotations
  • @JsonSerializable.new()

Constructors

Certificate(String version, BirthDate dateOfBirth, Identity holder, List<Vaccine>? vaccines, List<Test>? tests, List<Recovery>? recoveries)
Certificate.fromJson(Map<String, dynamic> json)
factory

Properties

dateOfBirth → BirthDate
final
hashCode → int
The hash code for this object.
no setterinherited
holder → Identity
final
recoveries → List<Recovery>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tests → List<Test>?
final
vaccines → List<Vaccine>?
final
version → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited